@@ -13,14 +13,16 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from typing import Union
+
+from selenium.webdriver.remote.webelement import WebElement
 
 from SeleniumLibrary.base import LibraryComponent, keyword
 
 
 class FrameKeywords(LibraryComponent):
-
     @keyword
-    def select_frame(self, locator):
+    def select_frame(self, locator: Union[WebElement, str]):
         """Sets frame identified by ``locator`` as the current frame.
 
         See the `Locating elements` section for details about the locator
@@ -35,7 +37,7 @@ class FrameKeywords(LibraryComponent):
         | `Unselect Frame` |           | # Back to main frame.                        |
         | `Select Frame`   | //iframe[@name='xxx'] | # Select frame using xpath       |
         """
-        self.info("Selecting frame '%s'." % locator)
+        self.info(f"Selecting frame '{locator}'.")
         element = self.find_element(locator)
         self.driver.switch_to.frame(element)
 
@@ -48,7 +50,7 @@ class FrameKeywords(LibraryComponent):
         self.driver.switch_to.default_content()
 
     @keyword
-    def current_frame_should_contain(self, text, loglevel='TRACE'):
+    def current_frame_should_contain(self, text: str, loglevel: str = "TRACE"):
         """Verifies that the current frame contains ``text``.
 
         See `Page Should Contain` for an explanation about the ``loglevel``
@@ -59,12 +61,13 @@ class FrameKeywords(LibraryComponent):
         """
         if not self.is_text_present(text):
             self.log_source(loglevel)
-            raise AssertionError("Frame should have contained text '%s' "
-                                 "but did not." % text)
-        self.info("Current frame contains text '%s'." % text)
+            raise AssertionError(
+                f"Frame should have contained text '{text}' but did not."
+            )
+        self.info(f"Current frame contains text '{text}'.")
 
     @keyword
-    def current_frame_should_not_contain(self, text, loglevel='TRACE'):
+    def current_frame_should_not_contain(self, text: str, loglevel: str = "TRACE"):
         """Verifies that the current frame does not contain ``text``.
 
         See `Page Should Contain` for an explanation about the ``loglevel``
@@ -72,12 +75,15 @@ class FrameKeywords(LibraryComponent):
         """
         if self.is_text_present(text):
             self.log_source(loglevel)
-            raise AssertionError("Frame should not have contained text '%s' "
-                                 "but it did." % text)
-        self.info("Current frame did not contain text '%s'." % text)
+            raise AssertionError(
+                f"Frame should not have contained text '{text}' but it did."
+            )
+        self.info(f"Current frame did not contain text '{text}'.")
 
     @keyword
-    def frame_should_contain(self, locator, text, loglevel='TRACE'):
+    def frame_should_contain(
+        self, locator: Union[WebElement, str], text: str, loglevel: str = "TRACE"
+    ):
         """Verifies that frame identified by ``locator`` contains ``text``.
 
         See the `Locating elements` section for details about the locator
@@ -88,14 +94,15 @@ class FrameKeywords(LibraryComponent):
         """
         if not self._frame_contains(locator, text):
             self.log_source(loglevel)
-            raise AssertionError("Frame '%s' should have contained text '%s' "
-                                 "but did not." % (locator, text))
-        self.info("Frame '%s' contains text '%s'." % (locator, text))
+            raise AssertionError(
+                f"Frame '{locator}' should have contained text '{text}' but did not."
+            )
+        self.info(f"Frame '{locator}' contains text '{text}'.")
 
-    def _frame_contains(self, locator, text):
+    def _frame_contains(self, locator: Union[WebElement, str], text: str):
         element = self.find_element(locator)
         self.driver.switch_to.frame(element)
-        self.info("Searching for text from frame '%s'." % locator)
+        self.info(f"Searching for text from frame '{locator}'.")
         found = self.is_text_present(text)
         self.driver.switch_to.default_content()
         return found
